mailr22683 - /trunk/specific_analyses/frame_order/api.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 10, 2014 - 16:42:
Author: bugman
Date: Thu Apr 10 16:42:04 2014
New Revision: 22683

URL: http://svn.gna.org/viewcvs/relax?rev=22683&view=rev
Log:
Docstring fixes for the frame order specific analysis API object.

A number of the methods were referring to the base data as being alignment 
tensors, but this has
changed to RDCs and PCSs a long time ago.


Modified:
    trunk/specific_analyses/frame_order/api.py

Modified: trunk/specific_analyses/frame_order/api.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/specific_analyses/frame_order/api.py?rev=22683&r1=22682&r2=22683&view=diff
==============================================================================
--- trunk/specific_analyses/frame_order/api.py  (original)
+++ trunk/specific_analyses/frame_order/api.py  Thu Apr 10 16:42:04 2014
@@ -68,7 +68,7 @@
 
 
     def base_data_loop(self):
-        """Generator method for looping over the base data - alignment 
tensors, RDCs, PCSs.
+        """Generator method for looping over the base data - RDCs and PCSs.
 
         This loop yields the following:
 
@@ -134,7 +134,7 @@
 
 
     def create_mc_data(self, data_id=None):
-        """Create the Monte Carlo data by back calculating the reduced 
tensor data.
+        """Create the Monte Carlo data by back calculating the RDCs or PCSs.
 
         @keyword data_id:   The data set as yielded by the base_data_loop() 
generator method.
         @type data_id:      list of str
@@ -670,11 +670,11 @@
 
 
     def return_error(self, data_id):
         """Return the alignment tensor error structure.
 
         @param data_id:     The data set as yielded by the base_data_loop() 
generator method.
         @type data_id:      list of str
-        @return:            The array of tensor error values.
+        @return:            The array of RDC or PCS error values.
         @rtype:             list of float
         """
 
@@ -670,11 +670,11 @@
 
     def return_error(self, data_id):
-        """Return the alignment tensor error structure.
+        """Return the RDC or PCS error structure.
 
         @param data_id:     The data set as yielded by the base_data_loop() 




Related Messages


Powered by MHonArc, Updated Thu Apr 10 17:20:02 2014